pub struct CrateIdentity {
pub name: &'static str,
pub responsibility: &'static str,
}Expand description
Minimal crate identity metadata used while the rest of the model is defined.
Fields
name: &'static strresponsibility: &'static strTrait Implementations
Sourceimpl Clone for CrateIdentity
impl Clone for CrateIdentity
Sourcefn clone(&self) -> CrateIdentity
fn clone(&self) -> CrateIdentity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CrateIdentity
impl Debug for CrateIdentity
Sourceimpl PartialEq for CrateIdentity
impl PartialEq for CrateIdentity
Sourcefn eq(&self, other: &CrateIdentity) -> bool
fn eq(&self, other: &CrateIdentity) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CrateIdentity
impl StructuralPartialEq for CrateIdentity